@@ -79,7 +79,7 @@ def build_server(app, build, vcs, build_dir, output_dir, log_dir, force):
         if not buildserverid:
             buildserverid = subprocess.check_output(['vagrant', 'ssh', '-c',
                                                      'cat /home/vagrant/buildserverid'],
-                                                    cwd='builder').rstrip().decode()
+                                                    cwd='builder').strip().decode()
             logging.debug(_('Fetched buildserverid from VM: {buildserverid}')
                           .format(buildserverid=buildserverid))
 
@@ -105,14 +105,14 @@ def build_server(app, build, vcs, build_dir, output_dir, log_dir, force):
             logging.debug("rsyncing " + path + " to " + ftp.getcwd())
             # TODO this should move to `vagrant rsync` from >= v1.5
             try:
-                subprocess.check_output(['rsync', '--recursive', '--perms', '--links', '--quiet', '--rsh=' +
-                                         'ssh -o StrictHostKeyChecking=no' +
-                                         ' -o UserKnownHostsFile=/dev/null' +
-                                         ' -o LogLevel=FATAL' +
-                                         ' -o IdentitiesOnly=yes' +
-                                         ' -o PasswordAuthentication=no' +
-                                         ' -p ' + str(sshinfo['port']) +
-                                         ' -i ' + sshinfo['idfile'],
+                subprocess.check_output(['rsync', '--recursive', '--perms', '--links', '--quiet', '--rsh='
+                                         + 'ssh -o StrictHostKeyChecking=no'
+                                         + ' -o UserKnownHostsFile=/dev/null'
+                                         + ' -o LogLevel=FATAL'
+                                         + ' -o IdentitiesOnly=yes'
+                                         + ' -o PasswordAuthentication=no'
+                                         + ' -p ' + str(sshinfo['port'])
+                                         + ' -i ' + sshinfo['idfile'],
                                          path,
                                          sshinfo['user'] + "@" + sshinfo['hostname'] + ":" + ftp.getcwd()],
                                         stderr=subprocess.STDOUT)
@@ -828,28 +828,12 @@ def build_local(app, build, vcs, build_dir, output_dir, log_dir, srclib_dir, ext
 
     if common.get_file_extension(src) == 'apk':
         vercode, version = get_metadata_from_apk(app, build, src)
-        if (version != build.versionName or vercode != build.versionCode):
+        if version != build.versionName or vercode != build.versionCode:
             raise BuildException(("Unexpected version/version code in output;"
                                   " APK: '%s' / '%s', "
                                   " Expected: '%s' / '%s'")
                                  % (version, str(vercode), build.versionName,
                                     str(build.versionCode)))
-    else:
-        vercode = build.versionCode
-        version = build.versionName
-
-    # Add information for 'fdroid verify' to be able to reproduce the build
-    # environment.
-    if onserver:
-        metadir = os.path.join(tmp_dir, 'META-INF')
-        if not os.path.exists(metadir):
-            os.mkdir(metadir)
-        homedir = os.path.expanduser('~')
-        for fn in ['buildserverid', 'fdroidserverid']:
-            shutil.copyfile(os.path.join(homedir, fn),
-                            os.path.join(metadir, fn))
-            subprocess.call(['jar', 'uf', os.path.abspath(src),
-                             'META-INF/' + fn], cwd=tmp_dir)
 
     # Copy the unsigned apk to our destination directory for further
     # processing (by publish.py)...
@@ -1008,6 +992,12 @@ def main():
     if options.reset_server and not options.server:
         parser.error("option %s: Using --reset-server without --server makes no sense" % "reset-server")
 
+    if options.onserver or not options.server:
+        for d in ['build-tools', 'platform-tools', 'tools']:
+            if not os.path.isdir(os.path.join(config['sdk_path'], d)):
+                raise FDroidException(_("Android SDK '{path}' does not have '{dirname}' installed!")
+                                      .format(path=config['sdk_path'], dirname=d))
+
     log_dir = 'logs'
     if not os.path.isdir(log_dir):
         logging.info("Creating log directory")
@@ -1233,6 +1223,7 @@ def main():
                     txt = "* build session started at " + common.get_wiki_timestamp(start_timestamp) + '\n' \
                           + "* this build started at " + build_starttime + '\n' \
                           + "* this build completed at " + common.get_wiki_timestamp() + '\n' \
+                          + common.get_git_describe_link() \
                           + '* fdroidserverid: [https://gitlab.com/fdroid/fdroidserver/commit/' \
                           + fdroidserverid + ' ' + fdroidserverid + ']\n\n'
                     if buildserverid:
