@@ -32,7 +32,7 @@ import urllib.parse
 import zipfile
 import calendar
 from binascii import hexlify, unhexlify
-from datetime import datetime
+from datetime import datetime, timezone
 from xml.dom.minidom import Document
 
 from . import _
@@ -67,7 +67,7 @@ def make(apps, sortedids, apks, repodir, archive):
         common.assert_config_keystore(common.config)
 
     repodict = collections.OrderedDict()
-    repodict['timestamp'] = datetime.utcnow()
+    repodict['timestamp'] = datetime.utcnow().replace(tzinfo=timezone.utc)
     repodict['version'] = METADATA_VERSION
 
     if common.config['repo_maxage'] != 0:
@@ -163,7 +163,7 @@ def make_v1(apps, packages, repodir, repodict, requestsdict, fdroid_signing_key_
     output['requests'] = requestsdict
 
     # establish sort order of the index
-    v1_sort_packages(packages, repodir, fdroid_signing_key_fingerprints)
+    v1_sort_packages(packages, fdroid_signing_key_fingerprints)
 
     appslist = []
     output['apps'] = appslist
@@ -213,6 +213,16 @@ def make_v1(apps, packages, repodir, repodict, requestsdict, fdroid_signing_key_
         if packageName not in apps:
             logging.info(_('Ignoring package without metadata: ') + package['apkName'])
             continue
+        if not package.get('versionName'):
+            app = apps[packageName]
+            versionCodeStr = str(package['versionCode'])  # TODO build.versionCode should be int!
+            for build in app['builds']:
+                if build['versionCode'] == versionCodeStr:
+                    versionName = build.get('versionName')
+                    logging.info(_('Overriding blank versionName in {apkfilename} from metadata: {version}')
+                                 .format(apkfilename=package['apkName'], version=versionName))
+                    package['versionName'] = versionName
+                    break
         if packageName in output_packages:
             packagelist = output_packages[packageName]
         else:
@@ -242,7 +252,7 @@ def make_v1(apps, packages, repodir, repodict, requestsdict, fdroid_signing_key_
         signindex.sign_index_v1(repodir, json_name)
 
 
-def v1_sort_packages(packages, repodir, fdroid_signing_key_fingerprints):
+def v1_sort_packages(packages, fdroid_signing_key_fingerprints):
     """Sorts the supplied list to ensure a deterministic sort order for
     package entries in the index file. This sort-order also expresses
     installation preference to the clients.
@@ -479,7 +489,17 @@ def make_v0(apps, apks, repodir, repodict, requestsdict, fdroid_signing_key_fing
 
             apkel = doc.createElement("package")
             apel.appendChild(apkel)
-            addElement('version', apk['versionName'], doc, apkel)
+
+            versionName = apk.get('versionName')
+            if not versionName:
+                versionCodeStr = str(apk['versionCode'])  # TODO build.versionCode should be int!
+                for build in app.builds:
+                    if build['versionCode'] == versionCodeStr and 'versionName' in build:
+                        versionName = build['versionName']
+                        break
+            if versionName:
+                addElement('version', versionName, doc, apkel)
+
             addElement('versioncode', str(apk['versionCode']), doc, apkel)
             addElement('apkname', apk['apkName'], doc, apkel)
             addElementIfInApk('srcname', apk, 'srcname', doc, apkel)
