@@ -39,7 +39,7 @@ def disable_in_config(key, value):
     '''write a key/value to the local config.py, then comment it out'''
     with open('config.py', 'r', encoding='utf8') as f:
         data = f.read()
-    pattern = '\n[\s#]*' + key + '\s*=\s*"[^"]*"'
+    pattern = r'\n[\s#]*' + key + r'\s*=\s*"[^"]*"'
     repl = '\n#' + key + ' = "' + value + '"'
     data = re.sub(pattern, repl, data)
     with open('config.py', 'w', encoding='utf8') as f:
@@ -75,6 +75,8 @@ def main():
     # in ANDROID_HOME if that exists, otherwise None
     if options.android_home is not None:
         test_config['sdk_path'] = options.android_home
+    elif common.use_androguard():
+        pass
     elif not common.test_sdk_exists(test_config):
         if os.path.isfile('/usr/bin/aapt'):
             # remove sdk_path and build_tools, they are not required
@@ -104,13 +106,14 @@ def main():
                 except KeyboardInterrupt:
                     print('')
                     sys.exit(1)
-                if re.match('^\s*$', s) is not None:
+                if re.match(r'^\s*$', s) is not None:
                     test_config['sdk_path'] = default_sdk_path
                 else:
                     test_config['sdk_path'] = s
                 if common.test_sdk_exists(test_config):
                     break
-    if not common.test_sdk_exists(test_config):
+    if (options.android_home is not None or not common.use_androguard()) \
+       and not common.test_sdk_exists(test_config):
         raise FDroidException("Android SDK not found.")
 
     if not os.path.exists('config.py'):
@@ -206,8 +209,8 @@ def main():
                     opensc_so = files[0]
                 else:
                     opensc_so = '/usr/lib/opensc-pkcs11.so'
-                    logging.warn('No OpenSC PKCS#11 module found, ' +
-                                 'install OpenSC then edit "opensc-fdroid.cfg"!')
+                    logging.warn('No OpenSC PKCS#11 module found, '
+                                 + 'install OpenSC then edit "opensc-fdroid.cfg"!')
             with open(os.path.join(examplesdir, 'opensc-fdroid.cfg'), 'r') as f:
                 opensc_fdroid = f.read()
             opensc_fdroid = re.sub('^library.*', 'library = ' + opensc_so, opensc_fdroid,
