@@ -21,6 +21,7 @@ import glob
 import os
 import re
 import sys
+import urllib.parse
 
 from . import _
 from . import common
@@ -32,7 +33,7 @@ options = None
 
 
 def enforce_https(domain):
-    return (re.compile(r'.*[^sS]://[^/]*' + re.escape(domain) + r'(/.*)?'),
+    return (re.compile(r'^[^h][^t][^t][^p][^s]://[^/]*' + re.escape(domain) + r'(/.*)?', re.IGNORECASE),
             domain + " URLs should always use https://")
 
 
@@ -51,6 +52,9 @@ https_enforcings = [
     enforce_https('savannah.gnu.org'),
     enforce_https('git.savannah.gnu.org'),
     enforce_https('download.savannah.gnu.org'),
+    enforce_https('github.io'),
+    enforce_https('gitlab.io'),
+    enforce_https('githubusercontent.com'),
 ]
 
 
@@ -126,6 +130,7 @@ regex_checks = {
     'WebSite': http_checks,
     'SourceCode': http_checks,
     'Repo': https_enforcings,
+    'UpdateCheckMode': https_enforcings,
     'IssueTracker': http_checks + [
         (re.compile(r'.*github\.com/[^/]+/[^/]+/*$'),
          _("/issues is missing")),
@@ -164,7 +169,7 @@ regex_checks = {
          _("Unnecessary leading space")),
         (re.compile(r'.*\s$'),
          _("Unnecessary trailing space")),
-        (re.compile(r'.*<(iframe|link|script).*'),
+        (re.compile(r'.*<(applet|base|body|button|embed|form|head|html|iframe|img|input|link|object|picture|script|source|style|svg|video).*', re.IGNORECASE),
          _("Forbidden HTML tags")),
         (re.compile(r'''.*\s+src=["']javascript:.*'''),
          _("Javascript in HTML src attributes")),
@@ -203,6 +208,25 @@ def get_lastbuild(builds):
     return lastbuild
 
 
+def check_update_check_data_url(app):
+    """UpdateCheckData must have a valid HTTPS URL to protect checkupdates runs
+    """
+    if app.UpdateCheckData:
+        urlcode, codeex, urlver, verex = app.UpdateCheckData.split('|')
+        for url in (urlcode, urlver):
+            if url != '.':
+                parsed = urllib.parse.urlparse(url)
+                if not parsed.scheme or not parsed.netloc:
+                    yield _('UpdateCheckData not a valid URL: {url}').format(url=url)
+                if parsed.scheme != 'https':
+                    yield _('UpdateCheckData must use HTTPS URL: {url}').format(url=url)
+
+
+def check_vercode_operation(app):
+    if app.VercodeOperation and not common.VERCODE_OPERATION_RE.match(app.VercodeOperation):
+        yield _('Invalid VercodeOperation: {field}').format(field=app.VercodeOperation)
+
+
 def check_ucm_tags(app):
     lastbuild = get_lastbuild(app.builds)
     if (lastbuild is not None
@@ -509,6 +533,8 @@ def main():
 
         app_check_funcs = [
             check_regexes,
+            check_update_check_data_url,
+            check_vercode_operation,
             check_ucm_tags,
             check_char_limits,
             check_old_links,
@@ -535,95 +561,77 @@ def main():
 
 
 # A compiled, public domain list of official SPDX license tags from:
-# https://github.com/sindresorhus/spdx-license-list/blob/v3.0.1/spdx-simple.json
+# https://github.com/sindresorhus/spdx-license-list/blob/v4.0.0/spdx-simple.json
 # The deprecated license tags have been removed from the list, they are at the
 # bottom, starting after the last license tags that start with Z.
 # This is at the bottom, since its a long list of data
 SPDX = [
     "PublicDomain",  # an F-Droid addition, until we can enforce a better option
-    "Glide",
+    "0BSD",
+    "AAL",
     "Abstyles",
+    "Adobe-2006",
+    "Adobe-Glyph",
+    "ADSL",
     "AFL-1.1",
     "AFL-1.2",
     "AFL-2.0",
     "AFL-2.1",
     "AFL-3.0",
-    "AMPAS",
-    "APL-1.0",
-    "Adobe-Glyph",
-    "APAFML",
-    "Adobe-2006",
-    "AGPL-1.0",
     "Afmparse",
+    "AGPL-1.0",
+    "AGPL-3.0-only",
+    "AGPL-3.0-or-later",
     "Aladdin",
-    "ADSL",
     "AMDPLPA",
+    "AML",
+    "AMPAS",
     "ANTLR-PD",
     "Apache-1.0",
     "Apache-1.1",
     "Apache-2.0",
-    "AML",
+    "APAFML",
+    "APL-1.0",
     "APSL-1.0",
     "APSL-1.1",
     "APSL-1.2",
     "APSL-2.0",
-    "Artistic-1.0",
-    "Artistic-1.0-Perl",
     "Artistic-1.0-cl8",
+    "Artistic-1.0-Perl",
+    "Artistic-1.0",
     "Artistic-2.0",
-    "AAL",
     "Bahyph",
     "Barr",
     "Beerware",
     "BitTorrent-1.0",
     "BitTorrent-1.1",
-    "BSL-1.0",
     "Borceux",
-    "BSD-2-Clause",
+    "BSD-1-Clause",
     "BSD-2-Clause-FreeBSD",
     "BSD-2-Clause-NetBSD",
-    "BSD-3-Clause",
+    "BSD-2-Clause-Patent",
+    "BSD-2-Clause",
+    "BSD-3-Clause-Attribution",
     "BSD-3-Clause-Clear",
-    "BSD-3-Clause-No-Nuclear-License",
+    "BSD-3-Clause-LBNL",
     "BSD-3-Clause-No-Nuclear-License-2014",
+    "BSD-3-Clause-No-Nuclear-License",
     "BSD-3-Clause-No-Nuclear-Warranty",
+    "BSD-3-Clause",
+    "BSD-4-Clause-UC",
     "BSD-4-Clause",
     "BSD-Protection",
     "BSD-Source-Code",
-    "BSD-3-Clause-Attribution",
-    "0BSD",
-    "BSD-4-Clause-UC",
+    "BSL-1.0",
     "bzip2-1.0.5",
     "bzip2-1.0.6",
     "Caldera",
-    "CECILL-1.0",
-    "CECILL-1.1",
-    "CECILL-2.0",
-    "CECILL-2.1",
-    "CECILL-B",
-    "CECILL-C",
-    "ClArtistic",
-    "MIT-CMU",
-    "CNRI-Jython",
-    "CNRI-Python",
-    "CNRI-Python-GPL-Compatible",
-    "CPOL-1.02",
-    "CDDL-1.0",
-    "CDDL-1.1",
-    "CPAL-1.0",
-    "CPL-1.0",
     "CATOSL-1.1",
-    "Condor-1.1",
     "CC-BY-1.0",
     "CC-BY-2.0",
     "CC-BY-2.5",
     "CC-BY-3.0",
     "CC-BY-4.0",
-    "CC-BY-ND-1.0",
-    "CC-BY-ND-2.0",
-    "CC-BY-ND-2.5",
-    "CC-BY-ND-3.0",
-    "CC-BY-ND-4.0",
     "CC-BY-NC-1.0",
     "CC-BY-NC-2.0",
     "CC-BY-NC-2.5",
@@ -639,12 +647,35 @@ SPDX = [
     "CC-BY-NC-SA-2.5",
     "CC-BY-NC-SA-3.0",
     "CC-BY-NC-SA-4.0",
+    "CC-BY-ND-1.0",
+    "CC-BY-ND-2.0",
+    "CC-BY-ND-2.5",
+    "CC-BY-ND-3.0",
+    "CC-BY-ND-4.0",
     "CC-BY-SA-1.0",
     "CC-BY-SA-2.0",
     "CC-BY-SA-2.5",
     "CC-BY-SA-3.0",
     "CC-BY-SA-4.0",
     "CC0-1.0",
+    "CDDL-1.0",
+    "CDDL-1.1",
+    "CDLA-Permissive-1.0",
+    "CDLA-Sharing-1.0",
+    "CECILL-1.0",
+    "CECILL-1.1",
+    "CECILL-2.0",
+    "CECILL-2.1",
+    "CECILL-B",
+    "CECILL-C",
+    "ClArtistic",
+    "CNRI-Jython",
+    "CNRI-Python-GPL-Compatible",
+    "CNRI-Python",
+    "Condor-1.1",
+    "CPAL-1.0",
+    "CPL-1.0",
+    "CPOL-1.02",
     "Crossword",
     "CrystalStacker",
     "CUA-OPL-1.0",
@@ -652,131 +683,142 @@ SPDX = [
     "curl",
     "D-FSL-1.0",
     "diffmark",
-    "WTFPL",
     "DOC",
     "Dotseqn",
     "DSDP",
     "dvipdfm",
-    "EPL-1.0",
     "ECL-1.0",
     "ECL-2.0",
-    "eGenix",
     "EFL-1.0",
     "EFL-2.0",
-    "MIT-advertising",
-    "MIT-enna",
+    "eGenix",
     "Entessa",
+    "EPL-1.0",
+    "EPL-2.0",
     "ErlPL-1.1",
     "EUDatagrid",
     "EUPL-1.0",
     "EUPL-1.1",
+    "EUPL-1.2",
     "Eurosym",
     "Fair",
-    "MIT-feh",
     "Frameworx-1.0",
     "FreeImage",
-    "FTL",
     "FSFAP",
     "FSFUL",
     "FSFULLR",
+    "FTL",
+    "GFDL-1.1-only",
+    "GFDL-1.1-or-later",
+    "GFDL-1.2-only",
+    "GFDL-1.2-or-later",
+    "GFDL-1.3-only",
+    "GFDL-1.3-or-later",
     "Giftware",
     "GL2PS",
+    "Glide",
     "Glulxe",
-    "AGPL-3.0",
-    "GFDL-1.1",
-    "GFDL-1.2",
-    "GFDL-1.3",
-    "GPL-1.0",
-    "GPL-2.0",
-    "GPL-3.0",
-    "LGPL-2.1",
-    "LGPL-3.0",
-    "LGPL-2.0",
     "gnuplot",
+    "GPL-1.0-only",
+    "GPL-1.0-or-later",
+    "GPL-2.0-only",
+    "GPL-2.0-or-later",
+    "GPL-3.0-only",
+    "GPL-3.0-or-later",
     "gSOAP-1.3b",
     "HaskellReport",
     "HPND",
     "IBM-pibs",
-    "IPL-1.0",
     "ICU",
+    "IJG",
     "ImageMagick",
     "iMatix",
     "Imlib2",
-    "IJG",
     "Info-ZIP",
     "Intel-ACPI",
     "Intel",
     "Interbase-1.0",
     "IPA",
+    "IPL-1.0",
     "ISC",
     "JasPer-2.0",
     "JSON",
+    "LAL-1.2",
+    "LAL-1.3",
+    "Latex2e",
+    "Leptonica",
+    "LGPL-2.0-only",
+    "LGPL-2.0-or-later",
+    "LGPL-2.1-only",
+    "LGPL-2.1-or-later",
+    "LGPL-3.0-only",
+    "LGPL-3.0-or-later",
+    "LGPLLR",
+    "Libpng",
+    "libtiff",
+    "LiLiQ-P-1.1",
+    "LiLiQ-R-1.1",
+    "LiLiQ-Rplus-1.1",
+    "LPL-1.0",
+    "LPL-1.02",
     "LPPL-1.0",
     "LPPL-1.1",
     "LPPL-1.2",
     "LPPL-1.3a",
     "LPPL-1.3c",
-    "Latex2e",
-    "BSD-3-Clause-LBNL",
-    "Leptonica",
-    "LGPLLR",
-    "Libpng",
-    "libtiff",
-    "LAL-1.2",
-    "LAL-1.3",
-    "LiLiQ-P-1.1",
-    "LiLiQ-Rplus-1.1",
-    "LiLiQ-R-1.1",
-    "LPL-1.02",
-    "LPL-1.0",
     "MakeIndex",
-    "MTLL",
-    "MS-PL",
-    "MS-RL",
     "MirOS",
-    "MITNFA",
+    "MIT-advertising",
+    "MIT-CMU",
+    "MIT-enna",
+    "MIT-feh",
     "MIT",
+    "MITNFA",
     "Motosoto",
+    "mpich2",
     "MPL-1.0",
     "MPL-1.1",
-    "MPL-2.0",
     "MPL-2.0-no-copyleft-exception",
-    "mpich2",
+    "MPL-2.0",
+    "MS-PL",
+    "MS-RL",
+    "MTLL",
     "Multics",
     "Mup",
     "NASA-1.3",
     "Naumen",
     "NBPL-1.0",
+    "NCSA",
     "Net-SNMP",
     "NetCDF",
-    "NGPL",
-    "NOSL",
-    "NPL-1.0",
-    "NPL-1.1",
     "Newsletr",
+    "NGPL",
+    "NLOD-1.0",
     "NLPL",
     "Nokia",
-    "NPOSL-3.0",
-    "NLOD-1.0",
+    "NOSL",
     "Noweb",
+    "NPL-1.0",
+    "NPL-1.1",
+    "NPOSL-3.0",
     "NRL",
     "NTP",
-    "Nunit",
+    "OCCT-PL",
     "OCLC-2.0",
     "ODbL-1.0",
-    "PDDL-1.0",
-    "OCCT-PL",
+    "OFL-1.0",
+    "OFL-1.1",
     "OGTSL",
-    "OLDAP-2.2.2",
     "OLDAP-1.1",
     "OLDAP-1.2",
     "OLDAP-1.3",
     "OLDAP-1.4",
-    "OLDAP-2.0",
     "OLDAP-2.0.1",
+    "OLDAP-2.0",
     "OLDAP-2.1",
-    "OLDAP-2.2",
     "OLDAP-2.2.1",
+    "OLDAP-2.2.2",
+    "OLDAP-2.2",
     "OLDAP-2.3",
     "OLDAP-2.4",
     "OLDAP-2.5",
@@ -784,14 +826,15 @@ SPDX = [
     "OLDAP-2.7",
     "OLDAP-2.8",
     "OML",
+    "OpenSSL",
     "OPL-1.0",
+    "OSET-PL-2.1",
     "OSL-1.0",
     "OSL-1.1",
     "OSL-2.0",
     "OSL-2.1",
     "OSL-3.0",
-    "OpenSSL",
-    "OSET-PL-2.1",
+    "PDDL-1.0",
     "PHP-3.0",
     "PHP-3.01",
     "Plexus",
@@ -799,62 +842,60 @@ SPDX = [
     "psfrag",
     "psutils",
     "Python-2.0",
-    "QPL-1.0",
     "Qhull",
+    "QPL-1.0",
     "Rdisc",
-    "RPSL-1.0",
+    "RHeCos-1.1",
     "RPL-1.1",
     "RPL-1.5",
-    "RHeCos-1.1",
-    "RSCPL",
+    "RPSL-1.0",
     "RSA-MD",
+    "RSCPL",
     "Ruby",
     "SAX-PD",
     "Saxpath",
     "SCEA",
-    "SWL",
-    "SMPPL",
     "Sendmail",
     "SGI-B-1.0",
     "SGI-B-1.1",
     "SGI-B-2.0",
-    "OFL-1.0",
-    "OFL-1.1",
     "SimPL-2.0",
+    "SISSL-1.2",
+    "SISSL",
     "Sleepycat",
+    "SMLNJ",
+    "SMPPL",
     "SNIA",
     "Spencer-86",
     "Spencer-94",
     "Spencer-99",
-    "SMLNJ",
-    "SugarCRM-1.1.3",
-    "SISSL",
-    "SISSL-1.2",
     "SPL-1.0",
-    "Watcom-1.0",
+    "SugarCRM-1.1.3",
+    "SWL",
     "TCL",
     "TCP-wrappers",
-    "Unlicense",
     "TMate",
     "TORQUE-1.1",
     "TOSL",
     "Unicode-DFS-2015",
     "Unicode-DFS-2016",
     "Unicode-TOU",
+    "Unlicense",
     "UPL-1.0",
-    "NCSA",
     "Vim",
     "VOSTROM",
     "VSL-1.0",
-    "W3C-20150513",
     "W3C-19980720",
+    "W3C-20150513",
     "W3C",
+    "Watcom-1.0",
     "Wsuipa",
-    "Xnet",
+    "WTFPL",
     "X11",
     "Xerox",
     "XFree86-1.1",
     "xinetd",
+    "Xnet",
     "xpp",
     "XSkat",
     "YPL-1.0",
@@ -863,8 +904,8 @@ SPDX = [
     "Zend-2.0",
     "Zimbra-1.3",
     "Zimbra-1.4",
-    "Zlib",
     "zlib-acknowledgement",
+    "Zlib",
     "ZPL-1.1",
     "ZPL-2.0",
     "ZPL-2.1",
