@@ -36,7 +36,7 @@ def extract_signature(apkpath):
         raise FDroidException("no valid signature in '{}'".format(apkpath))
     logging.debug('signature okay: %s', apkpath)
 
-    appid, vercode, _ignored = common.get_apk_id_aapt(apkpath)
+    appid, vercode, _ignored = common.get_apk_id(apkpath)
     sigdir = common.metadata_get_sigdir(appid, vercode)
     if not os.path.exists(sigdir):
         os.makedirs(sigdir)
@@ -45,7 +45,7 @@ def extract_signature(apkpath):
     return sigdir
 
 
-def extract(config, options):
+def extract(options):
 
     # Create tmp dir if missing…
     tmp_dir = 'tmp'
@@ -57,7 +57,7 @@ def extract(config, options):
         sys.exit(1)
 
     # iterate over supplied APKs downlaod and extract them…
-    httpre = re.compile('https?:\/\/')
+    httpre = re.compile(r'https?:\/\/')
     for apk in options.APK:
         try:
             if os.path.isfile(apk):
