@@ -368,8 +368,8 @@ class LibvirtBuildVm(FDroidBuildVm):
     def package(self, output=None, keep_box_file=False):
         if not output:
             output = "buildserver.box"
-            logger.debug('no output name set for packaging \'%s\',' +
-                         'defaulting to %s', self.srvname, output)
+            logger.debug('no output name set for packaging \'%s\','
+                         + 'defaulting to %s', self.srvname, output)
         storagePool = self.conn.storagePoolLookupByName('default')
         domainInfo = self.conn.lookupByName(self.srvname).info()
         if storagePool:
@@ -434,8 +434,8 @@ class LibvirtBuildVm(FDroidBuildVm):
                 os.remove('box.img')
 
         else:
-            logger.warn('could not connect to storage-pool \'default\',' +
-                        'skipping packaging buildserver box')
+            logger.warn('could not connect to storage-pool \'default\','
+                        + 'skipping packaging buildserver box')
 
     def box_add(self, boxname, boxfile, force=True):
         boximg = '%s_vagrant_box_image_0.img' % (boxname)
@@ -444,7 +444,7 @@ class LibvirtBuildVm(FDroidBuildVm):
                 _check_call(['virsh', '-c', 'qemu:///system', 'vol-delete', '--pool', 'default', boximg])
                 logger.debug("removed old box image '%s' from libvirt storeage pool", boximg)
             except subprocess.CalledProcessError as e:
-                logger.debug("tired removing old box image '%s', file was not present in first place", boximg, exc_info=e)
+                logger.debug("tried removing old box image '%s', file was not present in first place", boximg, exc_info=e)
         super().box_add(boxname, boxfile, force)
 
     def box_remove(self, boxname):
@@ -452,7 +452,7 @@ class LibvirtBuildVm(FDroidBuildVm):
         try:
             _check_call(['virsh', '-c', 'qemu:///system', 'vol-delete', '--pool', 'default', '%s_vagrant_box_image_0.img' % (boxname)])
         except subprocess.CalledProcessError as e:
-            logger.debug("tired removing '%s', file was not present in first place", boxname, exc_info=e)
+            logger.debug("tried removing '%s', file was not present in first place", boxname, exc_info=e)
 
     def snapshot_create(self, snapshot_name):
         logger.info("creating snapshot '%s' for vm '%s'", snapshot_name, self.srvname)
